@@ -55,10 +55,24 @@ class ProxyManager:
                  proxy_info_dict: Dict[str, List[str]],
                  num_executors=32,
                  executor_queue_size=1000,
-                 verbose=False):
+                 verbose=False,
+                 new_session_fn=lambda: requests.Session()):
+        """
+        Create a new proxy manager. The manager has the internal thread workers, so to make it properly
+        work, use it as a context manager. ex) with ProxyManager(...) as proxy_manager: ...
+
+        :param test_url: url to test the availability of the proxy servers
+        :param proxy_info_dict: a dictionary of proxy servers. The key is the protocol, and the value is a list of the ip:port pairs
+        :param num_executors: number of threads to use for the executor
+        :param executor_queue_size: size of the executor queue
+        :param verbose: whether to print the success rate
+        :param new_session_fn: function to create a new session. By default, it creates a new requests.Session()
+        """
+
         self._test_url = test_url
         self._proxy_info_dict = proxy_info_dict
         self._verbose = verbose
+        self._new_session_fn = new_session_fn
 
         self._pool = self._init_pool(proxy_info_dict)
 
@@ -125,7 +139,7 @@ class ProxyManager:
 
             while not success:
                 with self._pool.poll() as proxy:
-                    session = requests.Session()
+                    session = self._new_session_fn()
 
                     session.proxies.update(proxy.info().as_requests_dict())
                     session.headers.update({'User-Agent': random_agent()})
